diff pcmu2efr/gen-efr.c @ 22:f4420403219a

pcmu2efr: change linear input gen to support 2nd frame
author Mychaela Falconia <falcon@freecalypso.org>
date Sun, 12 May 2024 03:40:27 +0000
parents 528eef871e23
children
line wrap: on
line diff
--- a/pcmu2efr/gen-efr.c	Sun May 12 03:15:23 2024 +0000
+++ b/pcmu2efr/gen-efr.c	Sun May 12 03:40:27 2024 +0000
@@ -1,5 +1,5 @@
 /*
  * The code in this module takes linear_inputs[][] from gen160.c
  * and generates standard EFR-encoded frames.
  */
 
@@ -8,7 +8,7 @@
 #include <stdlib.h>
 #include <gsm_efr.h>
 
-extern uint16_t linear_inputs[160][160];
+extern uint16_t linear_input_array[480];
 
 uint8_t standard_efr[160][31];
 
@@ -25,7 +25,7 @@
 	}
 	for (m = 0; m < 160; m++) {
 		EFR_encoder_reset(st, 0);
-		EFR_encode_frame(st, (const int16_t *) linear_inputs[m],
+		EFR_encode_frame(st, (const int16_t *) linear_input_array+160-m,
 				 standard_efr[m], (int *) 0, (int *) 0);
 	}
 	free(st);
@@ -1,5 +1,5 @@
 /*
- * The code in this module takes linear_inputs[][] from gen160.c
+ * The code in this module takes linear_input_array[] from gen160.c
  * and generates standard EFR-encoded frames.
  */